OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Σκοτεινό θέμα",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Ένα σκοτεινό θέμα που διευκολύνει τα μάτια σας μειώνοντας την συνολική ακτινοβολία και φωτεινότητα. Είναι ακόμη υπό δοκιμή, οπότε θα σας παρακαλούσαμε να αναφέρετε οποιαδήποτε προβλήματα παρατηρηθούν.",
    "High contrast mode" : "Λειτουργία υψηλής αντίθεσης",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Λειτουργία με υψηλή αντίθεση για να διευκολύνει την πλοήγηση σας. Η οπτική ποιότητα θα είναι μειωμένη αλλά θα έχετε υψηλότερη ευκρίνεια.",
    "Dyslexia font" : "Γραμματοσειρά για δυσλεκτικούς",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "Η OpenDyslexic είναι μία δωρεάν γραμματοσειρά σχεδιασμένη ώστε να περιορίζει ορισμένα από τα πιο συνήθη προβλήματα που προκαλεί η δυσλεξία στην ανάγνωση",
    "Accessibility" : "Προσβασιμότητα",
    "Accessibility options for nextcloud" : "Ρυθμίσεις προσβασιμότητας του nextcloud.",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Προσφέρει πολλαπλές επιλογές προσβασιμότητας για να διευκολύνουν τη χρήση του Nextcloud",
    "Web Content Accessibility Guidelines" : "Οδηγίες προσβασιμότητας περιεχομένου ιστού",
    "our issue tracker" : "ο ανιχνευτής ζητημάτων μας",
    "our design team" : "η σχεδιαστική ομάδα μας",
    "Enable" : "Ενεργοποίηση",
    "High contrast theme" : "Θέμα υψηλής αντίθεσης",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Ένα θέμα με υψηλή αντίθεση για να διευκολύνει την πλοήγηση σας. Η οπτική ποιότητα θα είναι μειωμένη αλλά θα έχετε υψηλότερη ευκρίνεια.",
    "Dark theme (beta)" : "Σκοτεινό θέμα (δοκιμαστική έκδοση)",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "Η OpenDyslexic είναι μια ελεύθερη γραμματοσειρά που έχει σχεδιαστεί για να μετριάζει μερικά από τα κοινά σφάλματα ανάγνωσης που προκαλούνται από δυσλεξία. Η γραμματοσειρά δημιουργήθηκε από τον Abelardo Gonzalez, ο οποίος την κυκλοφόρησε με χρήση άδειας ανοικτού κώδικα.",
    "Provides multiple accessibilities options to ease your use of nextcloud" : "Προσφέρει πολλαπλές επιλογές προσβασιμότητας για να διευκολύνει τη χρήση του Nextcloud",
    "Themes" : "Θέματα",
    "Fonts" : "Γραμματοσειρές",
    "enabled" : "ενεργοποιημένο"
},
"nplurals=2; plural=(n != 1);");
